@@ -1,10 +1,10 @@
 package mongodb
 
 import (
+	"context"
 	"crypto/tls"
 	"crypto/x509"
 	"fmt"
-	"net"
 	"net/url"
 	"strings"
 	"sync"
@@ -13,13 +13,14 @@ import (
 	"github.com/influxdata/telegraf"
 	tlsint "github.com/influxdata/telegraf/plugins/common/tls"
 	"github.com/influxdata/telegraf/plugins/inputs"
-	"gopkg.in/mgo.v2"
+	"go.mongodb.org/mongo-driver/mongo"
+	"go.mongodb.org/mongo-driver/mongo/options"
+	"go.mongodb.org/mongo-driver/mongo/readpref"
 )
 
 type MongoDB struct {
 	Servers             []string
 	Ssl                 Ssl
-	mongos              map[string]*Server
 	GatherClusterStatus bool
 	GatherPerdbStats    bool
 	GatherColStats      bool
@@ -27,12 +28,14 @@ type MongoDB struct {
 	ColStatsDbs         []string
 	tlsint.ClientConfig
 
-	Log telegraf.Logger
+	Log telegraf.Logger `toml:"-"`
+
+	clients []*Server
 }
 
 type Ssl struct {
-	Enabled bool
-	CaCerts []string `toml:"cacerts"`
+	Enabled bool     `toml:"ssl_enabled" deprecated:"1.3.0;use 'tls_*' options instead"`
+	CaCerts []string `toml:"cacerts" deprecated:"1.3.0;use 'tls_ca' instead"`
 }
 
 var sampleConfig = `
@@ -41,7 +44,7 @@ var sampleConfig = `
   ## For example:
   ##   mongodb://user:auth_key@10.10.3.30:27017,
   ##   mongodb://10.10.3.33:18832,
-  servers = ["mongodb://127.0.0.1:27017"]
+  servers = ["mongodb://127.0.0.1:27017?connect=direct"]
 
   ## When true, collect cluster status
   ## Note that the query that counts jumbo chunks triggers a COLLSCAN, which
@@ -78,118 +81,103 @@ func (*MongoDB) Description() string {
 	return "Read metrics from one or many MongoDB servers"
 }
 
-var localhost = &url.URL{Host: "mongodb://127.0.0.1:27017"}
+func (m *MongoDB) Init() error {
+	var tlsConfig *tls.Config
+	if m.Ssl.Enabled {
+		// Deprecated TLS config
+		tlsConfig = &tls.Config{
+			InsecureSkipVerify: m.ClientConfig.InsecureSkipVerify,
+		}
+		if len(m.Ssl.CaCerts) == 0 {
+			return fmt.Errorf("you must explicitly set insecure_skip_verify to skip cerificate validation")
+		}
+
+		roots := x509.NewCertPool()
+		for _, caCert := range m.Ssl.CaCerts {
+			if ok := roots.AppendCertsFromPEM([]byte(caCert)); !ok {
+				return fmt.Errorf("failed to parse root certificate")
+			}
+		}
+		tlsConfig.RootCAs = roots
+	} else {
+		var err error
+		tlsConfig, err = m.ClientConfig.TLSConfig()
+		if err != nil {
+			return err
+		}
+	}
+
+	if len(m.Servers) == 0 {
+		m.Servers = []string{"mongodb://127.0.0.1:27017"}
+	}
+
+	for _, connURL := range m.Servers {
+		if !strings.HasPrefix(connURL, "mongodb://") && !strings.HasPrefix(connURL, "mongodb+srv://") {
+			// Preserve backwards compatibility for hostnames without a
+			// scheme, broken in go 1.8. Remove in Telegraf 2.0
+			connURL = "mongodb://" + connURL
+			m.Log.Warnf("Using %q as connection URL; please update your configuration to use an URL", connURL)
+		}
+
+		u, err := url.Parse(connURL)
+		if err != nil {
+			return fmt.Errorf("unable to parse connection URL: %q", err)
+		}
+
+		ctx, cancel := context.WithTimeout(context.Background(), 10*time.Second)
+		defer cancel() //nolint:revive
+
+		opts := options.Client().ApplyURI(connURL)
+		if tlsConfig != nil {
+			opts.TLSConfig = tlsConfig
+		}
+		if opts.ReadPreference == nil {
+			opts.ReadPreference = readpref.Nearest()
+		}
+
+		client, err := mongo.Connect(ctx, opts)
+		if err != nil {
+			return fmt.Errorf("unable to connect to MongoDB: %q", err)
+		}
+
+		err = client.Ping(ctx, opts.ReadPreference)
+		if err != nil {
+			return fmt.Errorf("unable to connect to MongoDB: %s", err)
+		}
+
+		server := &Server{
+			client:   client,
+			hostname: u.Host,
+			Log:      m.Log,
+		}
+		m.clients = append(m.clients, server)
+	}
+
+	return nil
+}
 
 // Reads stats from all configured servers accumulates stats.
 // Returns one of the errors encountered while gather stats (if any).
 func (m *MongoDB) Gather(acc telegraf.Accumulator) error {
-	if len(m.Servers) == 0 {
-		return m.gatherServer(m.getMongoServer(localhost), acc)
-	}
-
 	var wg sync.WaitGroup
-	for i, serv := range m.Servers {
-		if !strings.HasPrefix(serv, "mongodb://") {
-			// Preserve backwards compatibility for hostnames without a
-			// scheme, broken in go 1.8. Remove in Telegraf 2.0
-			serv = "mongodb://" + serv
-			m.Log.Warnf("Using %q as connection URL; please update your configuration to use an URL", serv)
-			m.Servers[i] = serv
-		}
-
-		u, err := url.Parse(serv)
-		if err != nil {
-			m.Log.Errorf("Unable to parse address %q: %s", serv, err.Error())
-			continue
-		}
-		if u.Host == "" {
-			m.Log.Errorf("Unable to parse address %q", serv)
-			continue
-		}
-
+	for _, client := range m.clients {
 		wg.Add(1)
 		go func(srv *Server) {
 			defer wg.Done()
-			err := m.gatherServer(srv, acc)
+			err := srv.gatherData(acc, m.GatherClusterStatus, m.GatherPerdbStats, m.GatherColStats, m.GatherTopStat, m.ColStatsDbs)
 			if err != nil {
-				m.Log.Errorf("Error in plugin: %v", err)
+				m.Log.Errorf("failed to gather data: %q", err)
 			}
-		}(m.getMongoServer(u))
+		}(client)
 	}
 
 	wg.Wait()
 	return nil
 }
 
-func (m *MongoDB) getMongoServer(url *url.URL) *Server {
-	if _, ok := m.mongos[url.Host]; !ok {
-		m.mongos[url.Host] = &Server{
-			Log: m.Log,
-			URL: url,
-		}
-	}
-	return m.mongos[url.Host]
-}
-
-func (m *MongoDB) gatherServer(server *Server, acc telegraf.Accumulator) error {
-	if server.Session == nil {
-		var dialAddrs []string
-		if server.URL.User != nil {
-			dialAddrs = []string{server.URL.String()}
-		} else {
-			dialAddrs = []string{server.URL.Host}
-		}
-		dialInfo, err := mgo.ParseURL(dialAddrs[0])
-		if err != nil {
-			return fmt.Errorf("unable to parse URL %q: %s", dialAddrs[0], err.Error())
-		}
-		dialInfo.Direct = true
-		dialInfo.Timeout = 5 * time.Second
-
-		var tlsConfig *tls.Config
-
-		if m.Ssl.Enabled {
-			// Deprecated TLS config
-			tlsConfig = &tls.Config{}
-			if len(m.Ssl.CaCerts) > 0 {
-				roots := x509.NewCertPool()
-				for _, caCert := range m.Ssl.CaCerts {
-					ok := roots.AppendCertsFromPEM([]byte(caCert))
-					if !ok {
-						return fmt.Errorf("failed to parse root certificate")
-					}
-				}
-				tlsConfig.RootCAs = roots
-			} else {
-				tlsConfig.InsecureSkipVerify = true
-			}
-		} else {
-			tlsConfig, err = m.ClientConfig.TLSConfig()
-			if err != nil {
-				return err
-			}
-		}
-
-		// If configured to use TLS, add a dial function
-		if tlsConfig != nil {
-			dialInfo.DialServer = func(addr *mgo.ServerAddr) (net.Conn, error) {
-				return tls.Dial("tcp", addr.String(), tlsConfig)
-			}
-		}
-
-		sess, err := mgo.DialWithInfo(dialInfo)
-		if err != nil {
-			return fmt.Errorf("unable to connect to MongoDB: %s", err.Error())
-		}
-		server.Session = sess
-	}
-	return server.gatherData(acc, m.GatherClusterStatus, m.GatherPerdbStats, m.GatherColStats, m.GatherTopStat, m.ColStatsDbs)
-}
-
 func init() {
 	inputs.Add("mongodb", func() telegraf.Input {
 		return &MongoDB{
-			mongos:              make(map[string]*Server),
 			GatherClusterStatus: true,
 			GatherPerdbStats:    false,
 			GatherColStats:      false,
