@@ -9,6 +9,7 @@ import (
 	"time"
 
 	"github.com/google/go-cmp/cmp"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/testutil"
 )
@@ -649,10 +650,12 @@ func postThriftData(datafile, address, contentType string) error {
 
 	req.Header.Set("Content-Type", contentType)
 	client := &http.Client{}
-	_, err = client.Do(req)
+	resp, err := client.Do(req)
 	if err != nil {
 		return fmt.Errorf("HTTP POST request to zipkin endpoint %s failed %v", address, err)
 	}
 
+	defer resp.Body.Close()
+
 	return nil
 }
