@@ -6,11 +6,11 @@ import (
 	"testing"
 	"time"
 
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf/internal/templating"
 	"github.com/influxdata/telegraf/metric"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 )
 
 func BenchmarkParse(b *testing.B) {
@@ -30,7 +30,8 @@ func BenchmarkParse(b *testing.B) {
 	}
 
 	for i := 0; i < b.N; i++ {
-		p.Parse([]byte("servers.localhost.cpu.load 11 1435077219"))
+		_, err := p.Parse([]byte("servers.localhost.cpu.load 11 1435077219"))
+		require.NoError(b, err)
 	}
 }
 
@@ -285,7 +286,7 @@ func TestParseLine(t *testing.T) {
 			t.Fatalf("unexpected error creating graphite parser: %v", err)
 		}
 
-		metric, err := p.ParseLine(test.input)
+		m, err := p.ParseLine(test.input)
 		if errstr(err) != test.err {
 			t.Fatalf("err does not match.  expected %v, got %v", test.err, err)
 		}
@@ -293,22 +294,22 @@ func TestParseLine(t *testing.T) {
 			// If we erred out,it was intended and the following tests won't work
 			continue
 		}
-		if metric.Name() != test.measurement {
+		if m.Name() != test.measurement {
 			t.Fatalf("name parse failer.  expected %v, got %v",
-				test.measurement, metric.Name())
+				test.measurement, m.Name())
 		}
-		if len(metric.Tags()) != len(test.tags) {
+		if len(m.Tags()) != len(test.tags) {
 			t.Fatalf("tags len mismatch.  expected %d, got %d",
-				len(test.tags), len(metric.Tags()))
+				len(test.tags), len(m.Tags()))
 		}
-		f := metric.Fields()["value"].(float64)
+		f := m.Fields()["value"].(float64)
 		if f != test.value {
 			t.Fatalf("floatValue value mismatch.  expected %v, got %v",
 				test.value, f)
 		}
-		if metric.Time().UnixNano()/1000000 != test.time.UnixNano()/1000000 {
+		if m.Time().UnixNano()/1000000 != test.time.UnixNano()/1000000 {
 			t.Fatalf("time value mismatch.  expected %v, got %v",
-				test.time.UnixNano(), metric.Time().UnixNano())
+				test.time.UnixNano(), m.Time().UnixNano())
 		}
 	}
 }
@@ -478,9 +479,9 @@ func TestFilterMatchDefault(t *testing.T) {
 		time.Unix(1435077219, 0))
 
 	m, err := p.ParseLine("miss.servers.localhost.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	assert.Equal(t, exp, m)
+	require.Equal(t, exp, m)
 }
 
 func TestFilterMatchMultipleMeasurement(t *testing.T) {
@@ -495,9 +496,9 @@ func TestFilterMatchMultipleMeasurement(t *testing.T) {
 		time.Unix(1435077219, 0))
 
 	m, err := p.ParseLine("servers.localhost.cpu.cpu_load.10 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	assert.Equal(t, exp, m)
+	require.Equal(t, exp, m)
 }
 
 func TestFilterMatchMultipleMeasurementSeparator(t *testing.T) {
@@ -505,7 +506,7 @@ func TestFilterMatchMultipleMeasurementSeparator(t *testing.T) {
 		[]string{"servers.localhost .host.measurement.measurement*"},
 		nil,
 	)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	exp := metric.New("cpu_cpu_load_10",
 		map[string]string{"host": "localhost"},
@@ -513,9 +514,9 @@ func TestFilterMatchMultipleMeasurementSeparator(t *testing.T) {
 		time.Unix(1435077219, 0))
 
 	m, err := p.ParseLine("servers.localhost.cpu.cpu_load.10 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	assert.Equal(t, exp, m)
+	require.Equal(t, exp, m)
 }
 
 func TestFilterMatchSingle(t *testing.T) {
@@ -530,9 +531,9 @@ func TestFilterMatchSingle(t *testing.T) {
 		time.Unix(1435077219, 0))
 
 	m, err := p.ParseLine("servers.localhost.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	assert.Equal(t, exp, m)
+	require.Equal(t, exp, m)
 }
 
 func TestParseNoMatch(t *testing.T) {
@@ -547,9 +548,9 @@ func TestParseNoMatch(t *testing.T) {
 		time.Unix(1435077219, 0))
 
 	m, err := p.ParseLine("servers.localhost.memory.VmallocChunk 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	assert.Equal(t, exp, m)
+	require.Equal(t, exp, m)
 }
 
 func TestFilterMatchWildcard(t *testing.T) {
@@ -564,9 +565,9 @@ func TestFilterMatchWildcard(t *testing.T) {
 		time.Unix(1435077219, 0))
 
 	m, err := p.ParseLine("servers.localhost.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	assert.Equal(t, exp, m)
+	require.Equal(t, exp, m)
 }
 
 func TestFilterMatchExactBeforeWildcard(t *testing.T) {
@@ -583,9 +584,9 @@ func TestFilterMatchExactBeforeWildcard(t *testing.T) {
 		time.Unix(1435077219, 0))
 
 	m, err := p.ParseLine("servers.localhost.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	assert.Equal(t, exp, m)
+	require.Equal(t, exp, m)
 }
 
 func TestFilterMatchMostLongestFilter(t *testing.T) {
@@ -602,7 +603,7 @@ func TestFilterMatchMostLongestFilter(t *testing.T) {
 	}
 
 	m, err := p.ParseLine("servers.localhost.cpu.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	value, ok := m.GetTag("host")
 	require.True(t, ok)
@@ -631,9 +632,9 @@ func TestFilterMatchMultipleWildcards(t *testing.T) {
 		time.Unix(1435077219, 0))
 
 	m, err := p.ParseLine("servers.server01.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	assert.Equal(t, exp, m)
+	require.Equal(t, exp, m)
 }
 
 func TestParseDefaultTags(t *testing.T) {
@@ -647,7 +648,7 @@ func TestParseDefaultTags(t *testing.T) {
 	}
 
 	m, err := p.ParseLine("servers.localhost.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	value, ok := m.GetTag("host")
 	require.True(t, ok)
@@ -672,7 +673,7 @@ func TestParseDefaultTemplateTags(t *testing.T) {
 	}
 
 	m, err := p.ParseLine("servers.localhost.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	value, ok := m.GetTag("host")
 	require.True(t, ok)
@@ -698,7 +699,7 @@ func TestParseDefaultTemplateTagsOverridGlobal(t *testing.T) {
 
 	m, err := p.ParseLine("servers.localhost.cpu_load 11 1435077219")
 	_ = m
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	value, ok := m.GetTag("host")
 	require.True(t, ok)
@@ -725,7 +726,7 @@ func TestParseTemplateWhitespace(t *testing.T) {
 	}
 
 	m, err := p.ParseLine("servers.localhost.cpu_load 11 1435077219")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	value, ok := m.GetTag("host")
 	require.True(t, ok)
@@ -745,10 +746,11 @@ func TestApplyTemplate(t *testing.T) {
 	p, err := NewGraphiteParser("_",
 		[]string{"current.* measurement.measurement"},
 		nil)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	measurement, _, _, _ := p.ApplyTemplate("current.users")
-	assert.Equal(t, "current_users", measurement)
+	measurement, _, _, err := p.ApplyTemplate("current.users")
+	require.NoError(t, err)
+	require.Equal(t, "current_users", measurement)
 }
 
 // Test basic functionality of ApplyTemplate
@@ -756,10 +758,11 @@ func TestApplyTemplateNoMatch(t *testing.T) {
 	p, err := NewGraphiteParser(".",
 		[]string{"foo.bar measurement.measurement"},
 		nil)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
-	measurement, _, _, _ := p.ApplyTemplate("current.users")
-	assert.Equal(t, "current.users", measurement)
+	measurement, _, _, err := p.ApplyTemplate("current.users")
+	require.NoError(t, err)
+	require.Equal(t, "current.users", measurement)
 }
 
 // Test that most specific template is chosen
@@ -769,10 +772,10 @@ func TestApplyTemplateSpecific(t *testing.T) {
 			"current.* measurement.measurement",
 			"current.*.* measurement.measurement.service",
 		}, nil)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	measurement, tags, _, _ := p.ApplyTemplate("current.users.facebook")
-	assert.Equal(t, "current_users", measurement)
+	require.Equal(t, "current_users", measurement)
 
 	service, ok := tags["service"]
 	if !ok {
@@ -786,10 +789,10 @@ func TestApplyTemplateSpecific(t *testing.T) {
 func TestApplyTemplateTags(t *testing.T) {
 	p, err := NewGraphiteParser("_",
 		[]string{"current.* measurement.measurement region=us-west"}, nil)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	measurement, tags, _, _ := p.ApplyTemplate("current.users")
-	assert.Equal(t, "current_users", measurement)
+	require.Equal(t, "current_users", measurement)
 
 	region, ok := tags["region"]
 	if !ok {
@@ -803,11 +806,11 @@ func TestApplyTemplateTags(t *testing.T) {
 func TestApplyTemplateField(t *testing.T) {
 	p, err := NewGraphiteParser("_",
 		[]string{"current.* measurement.measurement.field"}, nil)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	measurement, _, field, err := p.ApplyTemplate("current.users.logged_in")
-
-	assert.Equal(t, "current_users", measurement)
+	require.NoError(t, err)
+	require.Equal(t, "current_users", measurement)
 
 	if field != "logged_in" {
 		t.Errorf("Parser.ApplyTemplate unexpected result. got %s, exp %s",
@@ -818,11 +821,11 @@ func TestApplyTemplateField(t *testing.T) {
 func TestApplyTemplateMultipleFieldsTogether(t *testing.T) {
 	p, err := NewGraphiteParser("_",
 		[]string{"current.* measurement.measurement.field.field"}, nil)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	measurement, _, field, err := p.ApplyTemplate("current.users.logged_in.ssh")
-
-	assert.Equal(t, "current_users", measurement)
+	require.NoError(t, err)
+	require.Equal(t, "current_users", measurement)
 
 	if field != "logged_in_ssh" {
 		t.Errorf("Parser.ApplyTemplate unexpected result. got %s, exp %s",
@@ -833,11 +836,11 @@ func TestApplyTemplateMultipleFieldsTogether(t *testing.T) {
 func TestApplyTemplateMultipleFieldsApart(t *testing.T) {
 	p, err := NewGraphiteParser("_",
 		[]string{"current.* measurement.measurement.field.method.field"}, nil)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	measurement, _, field, err := p.ApplyTemplate("current.users.logged_in.ssh.total")
-
-	assert.Equal(t, "current_users", measurement)
+	require.NoError(t, err)
+	require.Equal(t, "current_users", measurement)
 
 	if field != "logged_in_total" {
 		t.Errorf("Parser.ApplyTemplate unexpected result. got %s, exp %s",
@@ -848,11 +851,11 @@ func TestApplyTemplateMultipleFieldsApart(t *testing.T) {
 func TestApplyTemplateGreedyField(t *testing.T) {
 	p, err := NewGraphiteParser("_",
 		[]string{"current.* measurement.measurement.field*"}, nil)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	measurement, _, field, err := p.ApplyTemplate("current.users.logged_in")
-
-	assert.Equal(t, "current_users", measurement)
+	require.NoError(t, err)
+	require.Equal(t, "current_users", measurement)
 
 	if field != "logged_in" {
 		t.Errorf("Parser.ApplyTemplate unexpected result. got %s, exp %s",
@@ -868,11 +871,12 @@ func TestApplyTemplateOverSpecific(t *testing.T) {
 		},
 		nil,
 	)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	measurement, tags, _, err := p.ApplyTemplate("net.server001.a.b 2")
-	assert.Equal(t, "net", measurement)
-	assert.Equal(t,
+	require.NoError(t, err)
+	require.Equal(t, "net", measurement)
+	require.Equal(t,
 		map[string]string{"host": "server001", "metric": "a.b"},
 		tags)
 }
@@ -887,17 +891,19 @@ func TestApplyTemplateMostSpecificTemplate(t *testing.T) {
 		},
 		nil,
 	)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 
 	measurement, tags, _, err := p.ApplyTemplate("net.server001.a.b.c 2")
-	assert.Equal(t, "net", measurement)
-	assert.Equal(t,
+	require.NoError(t, err)
+	require.Equal(t, "net", measurement)
+	require.Equal(t,
 		map[string]string{"host": "server001", "metric": "a.b.c"},
 		tags)
 
 	measurement, tags, _, err = p.ApplyTemplate("net.server001.a.b 2")
-	assert.Equal(t, "net", measurement)
-	assert.Equal(t,
+	require.NoError(t, err)
+	require.Equal(t, "net", measurement)
+	require.Equal(t,
 		map[string]string{"host": "server001", "metric": "a.b"},
 		tags)
 }
