@@ -1,7 +1,7 @@
 package xpath
 
 import (
-	"io/ioutil"
+	"os"
 	"path/filepath"
 	"strings"
 	"testing"
@@ -1196,6 +1196,10 @@ func TestTestCases(t *testing.T) {
 			name:     "message-pack",
 			filename: "testcases/tracker_msgpack.conf",
 		},
+		{
+			name:     "field and tag batch (json)",
+			filename: "testcases/field_tag_batch.conf",
+		},
 	}
 
 	parser := influx.NewParser(influx.NewMetricHandler())
@@ -1233,7 +1237,7 @@ func TestTestCases(t *testing.T) {
 				pbmsgtype = protofields[1]
 			}
 
-			content, err := ioutil.ReadFile(datafile)
+			content, err := os.ReadFile(datafile)
 			require.NoError(t, err)
 
 			// Get the expectations
@@ -1265,8 +1269,21 @@ func TestTestCases(t *testing.T) {
 	}
 }
 
+func TestProtobufImporting(t *testing.T) {
+	// Setup the parser and run it.
+	parser := &Parser{
+		Format:              "xpath_protobuf",
+		ProtobufMessageDef:  "person.proto",
+		ProtobufMessageType: "importtest.Person",
+		ProtobufImportPaths: []string{"testcases/protos"},
+		Configs:             []Config{},
+		Log:                 testutil.Logger{Name: "parsers.protobuf"},
+	}
+	require.NoError(t, parser.Init())
+}
+
 func loadTestConfiguration(filename string) (*Config, []string, error) {
-	buf, err := ioutil.ReadFile(filename)
+	buf, err := os.ReadFile(filename)
 	if err != nil {
 		return nil, nil, err
 	}
